@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -9,10 +9,6 @@
 #include <QDateTime>
 #include <QObject>
 
-#include "author.h"
-
-class EntriesModel;
-
 class Feed : public QObject
 {
     Q_OBJECT
@@ -24,7 +20,7 @@ class Feed : public QObject
     Q_PROPERTY(QString link READ link WRITE setLink NOTIFY linkChanged)
     Q_PROPERTY(QString description READ description WRITE setDescription NOTIFY descriptionChanged)
     Q_PROPERTY(QString groupName READ groupName WRITE setGroupName NOTIFY groupNameChanged)
-    Q_PROPERTY(QVector<Author *> authors READ authors WRITE setAuthors NOTIFY authorsChanged)
+    Q_PROPERTY(QString authors READ authors WRITE setAuthors NOTIFY authorsChanged)
     Q_PROPERTY(bool refreshing READ refreshing WRITE setRefreshing NOTIFY refreshingChanged)
     Q_PROPERTY(int deleteAfterCount READ deleteAfterCount WRITE setDeleteAfterCount NOTIFY deleteAfterCountChanged)
     Q_PROPERTY(int deleteAfterType READ deleteAfterType WRITE setDeleteAfterType NOTIFY deleteAfterTypeChanged)
@@ -35,13 +31,10 @@ class Feed : public QObject
     Q_PROPERTY(int unreadEntryCount READ unreadEntryCount NOTIFY unreadEntryCountChanged)
     Q_PROPERTY(int errorId READ errorId WRITE setErrorId NOTIFY errorIdChanged)
     Q_PROPERTY(QString errorString READ errorString WRITE setErrorString NOTIFY errorStringChanged)
-    Q_PROPERTY(EntriesModel *entries MEMBER m_entries CONSTANT)
 
 public:
     explicit Feed(int index);
 
-    ~Feed();
-
     QString url() const;
     QString name() const;
     QString displayName() const;
@@ -49,7 +42,7 @@ public:
     QString link() const;
     QString description() const;
     QString groupName() const;
-    QVector<Author *> authors() const;
+    QString authors() const;
     int deleteAfterCount() const;
     int deleteAfterType() const;
     QDateTime subscribed() const;
@@ -69,7 +62,7 @@ public:
     void setLink(const QString &link);
     void setDescription(const QString &description);
     void setGroupName(const QString &groupName);
-    void setAuthors(const QVector<Author *> &authors);
+    void setAuthors(const QString &authors);
     void setDeleteAfterCount(int count);
     void setDeleteAfterType(int type);
     void setLastUpdated(const QDateTime &lastUpdated);
@@ -88,7 +81,7 @@ Q_SIGNALS:
     void linkChanged(const QString &link);
     void descriptionChanged(const QString &description);
     void groupNameChanged(const QString &groupName);
-    void authorsChanged(const QVector<Author *> &authors);
+    void authorsChanged(const QString &authors);
     void deleteAfterCountChanged(int count);
     void deleteAfterTypeChanged(int type);
     void lastUpdatedChanged(const QDateTime &lastUpdated);
@@ -108,7 +101,7 @@ private:
     QString m_link;
     QString m_description;
     QString m_group_name;
-    QVector<Author *> m_authors;
+    QString m_authors;
     int m_deleteAfterCount;
     int m_deleteAfterType;
     QDateTime m_subscribed;
@@ -116,7 +109,6 @@ private:
     bool m_notify;
     int m_errorId;
     QString m_errorString;
-    EntriesModel *m_entries;
 
     bool m_refreshing = false;
 };
